Instalación
===========

Existen 2 formas de instalar la biblioteca, así
que veremos cada una por separado.

Opción 1 - Instalación fácil, para cada sistema operativo
---------------------------------------------------------

La forma mas sencilla de instalar pilas es descargando
alguna de las versiones empaquetadas desde nuestro sitio web:

http://www.pilas-engine.com.ar/descargas.html


Opción 2 - Avanzada, desde repositorios
---------------------------------------

Otra opción es descargar pilas e instalarlo directamente desde
nuestro respositio git.

Hay mas información sobre esta forma de instalación en nuestra
sección :ref:`ref_desarrolladores`.
